@@ -52,8 +52,8 @@ define('M3_TITLE_BRACKET_END',		'」');					// タイトルを括弧表記する
 // ########## システム関係 ##########
 // システム基本情報
 define('M3_SYSTEM_NAME',			'Magic3');		// システム名称
-define('M3_SYSTEM_VERSION',			'2.12.4');		// システムのバージョン
-define('M3_SYSTEM_RELEASE_DATE',	'2015/5/20');	// システムのリリース日付
+define('M3_SYSTEM_VERSION',			'2.12.5');		// システムのバージョン
+define('M3_SYSTEM_RELEASE_DATE',	'2015/5/23');	// システムのリリース日付
 define('M3_SYSTEM_ID',				'M3');			// コンポーネント識別用ID
 define('M3_SYSTEM_DESCRIPTION',		'Magic3 is open source cms and web communication platform.');		// システムの説明
 define('M3_SYSTEM_MIN_MEMORY',		'16M');			// 最小メモリ使用量
@@ -109,6 +109,8 @@ define('M3_TAG_MACRO_MARK',			'MARK');								// マーク置換キー
 define('M3_TAG_MACRO_IMAGE',		'IMAGE');								// サムネール画像置換キー
 define('M3_TAG_MACRO_AVATAR',		'AVATAR');								// アバター置換キー
 define('M3_TAG_MACRO_URL',			'URL');									// URL置換キー
+define('M3_TAG_MACRO_ACCOUNT',		'ACCOUNT');								// アカウント置換キー
+define('M3_TAG_MACRO_PASSWORD',		'PASSWORD');							// パスワード置換キー
 define('M3_TAG_MACRO_FILES',		'FILES');								// 添付ファイル置換キー
 define('M3_TAG_MACRO_PAGES',		'PAGES');								// ページリンク置換キー
 define('M3_TAG_MACRO_LINKS',		'LINKS');								// 関連リンク置換キー
@@ -120,6 +122,7 @@ define('M3_TAG_MACRO_PERMALINK',	'PERMALINK');							// パーマリンク置換
 define('M3_TAG_MACRO_RATE',			'RATE');								// 評価機能置換キー
 define('M3_TAG_MACRO_BUTTON',		'BUTTON');								// ボタン置換キー
 define('M3_TAG_MACRO_WIDGET',		'WIDGET');								// ウィジェット埋め込みキー
+define('M3_TAG_MACRO_OPTIONAL',		'OPTIONAL');							// 任意オプション置換キー
 define('M3_TAG_MACRO_SITE_NAME',		'SITE_NAME');						// サイト情報置換キー(サイト名)
 define('M3_TAG_MACRO_SITE_URL',			'SITE_URL');						// サイト情報置換キー(URL)
 define('M3_TAG_MACRO_SITE_DESCRIPTION',	'SITE_DESCRIPTION');				// サイト情報置換キー(簡易説明)
