@@ -1,6 +1,6 @@
 <?php
 /**
-* @version		$Id: application.php 4939 2012-06-05 09:45:54Z fishbone $
+* @version		$Id: application.php 5825 2013-03-14 09:25:40Z fishbone $
 * @package		Joomla
 * @copyright	Copyright (C) 2005 - 2008 Open Source Matters. All rights reserved.
 * @license		GNU/GPL, see LICENSE.php
@@ -179,7 +179,7 @@ class JApplication extends JObject
 //				$error = JError::raiseError(500, JText::sprintf('JLIB_APPLICATION_ERROR_APPLICATION_LOAD', $client));
 //				return $error;
 //			}
-			$instances[$client] = &$instance;*/
+			$instances[$client] = $instance;*/
 			$instances[$client] = new JSite($config);
 		}
 
@@ -706,9 +706,16 @@ class JApplication extends JObject
 	 */
 	public function getTemplate($params = false)
 	{
-//		return 'system';
 		global $gEnvManager;
 		
+		if ((bool) $params)
+		{
+			$template = new stdClass;
+			$template->template = $gEnvManager->getCurrentTemplateId();
+			//$template->params = new JRegistry;
+			$template->params = new JParameter();
+			return $template;
+		}
 		return $gEnvManager->getCurrentTemplateId();
 	}
 
@@ -1094,7 +1101,7 @@ class JSite extends JApplication
 	 * @return	object	The parameters object
 	 * @since	1.5
 	 */
-	function &getParams($option = null)
+	function getParams($option = null)
 	{
 		static $params = array();
 		$hash = '__default';
@@ -1105,10 +1112,10 @@ class JSite extends JApplication
 			if (!$option) {
 				$option = JRequest::getCmd('option');
 			}
-			$params[$hash] =& JComponentHelper::getParams($option);
+			$params[$hash] = JComponentHelper::getParams($option);
 
 			// Get menu parameters
-			$menus	=& JSite::getMenu();
+			$menus	= JSite::getMenu();
 			$menu	= $menus->getActive();
 
 			$title       = htmlspecialchars_decode($this->getCfg('sitename' ));
@@ -1136,7 +1143,7 @@ class JSite extends JApplication
 	 * @return	object	The parameters object
 	 * @since	1.5
 	 */
-/*	function &getPageParameters( $option = null )
+/*	function getPageParameters( $option = null )
 	{
 		return $this->getParams( $option );
 	}*/
@@ -1147,8 +1154,8 @@ class JSite extends JApplication
 	 * @return object JPathway.
 	 * @since 1.5
 	 */
-	//function &getMenu()
-	static function &getMenu($name = null, $options = array())
+	//function getMenu()
+	static function getMenu($name = null, $options = array())
 	{
 //		$options = array();
 //		$menu = parent::getMenu('site', $options);
