@@ -56,7 +56,8 @@ INSERT INTO blog_config
 ('use_multi_blog',          '0',         'マルチブログを使用',                 8),
 ('multi_blog_top_content',  '',          'マルチブログのトップ画面コンテンツ', 9),
 ('category_count',          '2',         '記事に設定可能なカテゴリ数',         10),
-('entry_default_image',      '0_72c.jpg;0_200c.jpg', '記事デフォルト画像', 0),
+('thumb_type',              's=80c.jpg;mw=160x120c.jpg;l=200c.jpg', '記事サムネールタイプ定義', 0),
+('entry_default_image',     '0_72c.jpg;0_80c.jpg;0_200c.jpg',       '記事デフォルト画像', 0),
 ('comment_user_limited',      '0',       'コメントのユーザ制限',                 0),
 ('layout_entry_single',   '<small>[#CT_AUTHOR#] [#CT_DATE#] [#CT_TIME#] [#BLOG_LINK#]</small>[#BODY#][#CATEGORY#][#LINKS#]', 'コンテンツレイアウト(記事詳細)',               0),
 ('layout_entry_list',   '[#TITLE#]<small>[#CT_AUTHOR#] [#CT_DATE#] [#CT_TIME#] [#BLOG_LINK#]</small>[#BODY#][#CATEGORY#][#COMMENT_LINK#]', 'コンテンツレイアウト(記事一覧)',               0),
@@ -203,6 +204,7 @@ INSERT INTO _templates
 ('bootstrap_yeti',                'bootstrap_yeti',                10,      0,              false,     true,             true,         0,             now()),
 ('bootstrap_cerulean',            'bootstrap_cerulean',            10,      0,              false,     true,             true,         0,             now()),
 ('bootstrap_united',              'bootstrap_united',              10,      0,              false,     true,             true,         0,             now()),
+('bootstrap_cerulean_head',       'bootstrap_cerulean_head',       10,      0,              false,     true,             true,         0,             now()),
 ('m/default',                     'm/default',                     0,       1,              true,      false,            true,         0,             now()),
 ('m/smallfont',                   'm/smallfont',                   0,       1,              true,      false,            true,         0,             now()),
 ('s/default_simple',              's/default_simple',              1,       2,              false,     false,            true,         0,             now()),
