@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2010 Magic3 Project.
+ * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: wikiParam.php 3474 2010-08-13 10:36:48Z fishbone $
+ * @version    SVN: $Id: wikiParam.php 4952 2012-06-09 09:56:59Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetDbPath() .	'/wiki_mainDb.php');
@@ -328,7 +328,7 @@ class WikiParam
 	 * @param array $matchData		検索マッチデータ
 	 * @return string				変換後データ
 	 */
-    function _replace_query_callback($matchData)
+    static function _replace_query_callback($matchData)
 	{
 		$destStr = $matchData[0];
 		if ($destStr == 'cmd=') $destStr = M3_REQUEST_PARAM_OPERATION_WIKI_COMMAND . '=';
